@@ -5,7 +5,7 @@ import json
 import os
 import shutil
 import time
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
 
 def openWindowsFolder(folder: str):
@@ -268,8 +268,8 @@ def hold(msg: Optional[str] = None, showInput: bool = True, *exitValueList: str)
             return inputValue
 
 
-IntFloatStr = Union[int, float, str]
-IntFloat = Union[int, float]
+IntFloatStr = int | float | str
+IntFloat = int | float
 
 
 def toFloat(value: IntFloatStr, default: float):
