@@ -3,7 +3,7 @@ import binascii
 import hashlib
 import os
 from functools import wraps
-from typing import Any, Awaitable, Optional
+from typing import Any, Coroutine, Optional
 
 import aiofiles
 import aiohttp
@@ -24,11 +24,17 @@ def setAsyncFileMaxNum(value: int):
     _maxAsyncFileNum = value
 
 
-async def asyncAwait(*taskList: Awaitable[Any]):
-    resultList: list[Any] = []
-    for task in taskList:
-        resultList.append(await task)
-    return resultList
+_asyncAwaitList: list[Coroutine[Any, Any, Any]] = []
+
+
+def asyncAppend(task: Coroutine[Any, Any, Any]):
+    _asyncAwaitList.append(task)
+
+
+async def asyncAwait():
+    result = await asyncio.gather(*_asyncAwaitList)
+    _asyncAwaitList.clear()
+    return result
 
 
 async def asyncWriteFile(file: str, content: str, encoding: str = 'utf8', newline: str = '\n'):
@@ -195,7 +201,7 @@ async def asyncDownload(url: str, file: str):
     await asyncWriteBinFile(file, result)
 
 
-def asyncWait(waitSeconds: float):
+def asyncTimeout(waitSeconds: float):
     def _log(func: Any):
         @wraps(func)
         async def wrapper(*args: Any, **kwargs: Any):
@@ -205,6 +211,10 @@ def asyncWait(waitSeconds: float):
     return _log
 
 
+def asyncRun(coroutine: Coroutine[Any, Any, None]):
+    # asyncio.run(coroutine)
+    asyncio.get_event_loop().run_until_complete(coroutine)
+
 # 两个方案都能解决问题
 # asyncio.run(runAsync())
 # =>
