@@ -1,5 +1,5 @@
 import struct
-from typing import Any, Union
+from typing import Any
 
 import chardet
 
@@ -25,7 +25,7 @@ class BytesWriter():
         formatStr += "".join(self.formatAry)
         return struct.pack(formatStr, *self.valueAry)
 
-    def _write(self, format: str, value: Union[int, float, bool, str, bytes]):
+    def _write(self, format: str, value: int | float | bool | str | bytes):
         self.formatAry.append(format)
         self.valueAry.append(value)
 
